﻿using System;
using WpfRatingSelector.Models;

namespace WpfRatingSelector.ViewModels
{
	/// <summary>
	/// Song の Model と View を仲介します。
	/// </summary>
	class SongViewModel : ViewModelBase
	{
		/// <summary>
		/// インスタンスを初期化します。
		/// </summary>
		/// <param name="song"></param>
		public SongViewModel( Song song )
		{
			this._song    = song;
			this.Duration = String.Format( "{0:d2}:{1:d2}:{2:d2}", song.Duration.Hours, song.Duration.Minutes, song.Duration.Seconds );
		}

		/// <summary>
		/// アルバム名を取得または設定します。
		/// </summary>
		public string Album
		{
			get
			{
				return this._song.Album;
			}
			set
			{
				this._song.Album = value;
				this.NotifyPropertyChanged( "Album" );
			}
		}

		/// <summary>
		/// アーティスト名を取得または設定します。
		/// </summary>
		public string Artist
		{
			get
			{
				return this._song.Artist;
			}
			set
			{
				this._song.Artist = value;
				this.NotifyPropertyChanged( "Artist" );
			}
		}

		/// <summary>
		/// 演奏時間を取得します。
		/// </summary>
		public string Duration { get; private set; }

		/// <summary>
		/// 評価を示す値を取得または設定します。
		/// </summary>
		public int Rating
		{
			get
			{
				return this._song.Rating;
			}
			set
			{
				this._song.Rating = value;
				this.NotifyPropertyChanged( "Rating" );
			}
		}

		/// <summary>
		/// タイトルを取得または設定します。
		/// </summary>
		public string Title
		{
			get
			{
				return this._song.Title;
			}
			set
			{
				this._song.Title = value;
				this.NotifyPropertyChanged( "Title" );
			}
		}

		/// <summary>
		/// Model となる Song インスタンス。
		/// </summary>
		private Song _song;
	}
}
